@@ -3,8 +3,9 @@ package SOAP::GenericHashSerializer;
 use strict;
 use vars qw($VERSION);
 use SOAP::Defs;
+use SOAP::Serializer;
 
-$VERSION = '0.23';
+$VERSION = '0.25';
 
 sub new {
     my ($class, $hash) = @_;
@@ -21,21 +22,28 @@ my $g_intrusive_hash_keys = {
 };
 
 sub serialize {
-    my ($self, $stream) = @_;
+    my ($self, $stream, $envelope) = @_;
 
     my $hash = $self->{hash};
 
     while (my ($k, $v) = each %$hash) {
         next if exists $g_intrusive_hash_keys->{$k};
-        if (ref $v) {
-            $stream->reference_accessor(undef, $k, $v);
-        }
-        else {
-            $stream->simple_accessor(undef, $k, undef, undef, $v);
-        }
+	_serialize_object($stream, $envelope, undef, $k, $v);
     }
 }
 
+sub is_compound {
+    1;
+}
+
+sub is_multiref {
+    1;
+}
+
+sub is_package {
+    0;
+}
+
 sub get_typeinfo {
     my $self = shift;
     my $hash = $self->{hash};
@@ -49,14 +57,6 @@ sub get_typeinfo {
     ($typeuri, $typename);
 }
 
-sub is_package {
-    0;
-}
-
-sub get_accessor_type {
-    $soapperl_accessor_type_compound;
-}
-
 1;
 __END__
 
@@ -69,6 +69,16 @@ SOAP::GenericHashSerializer - Generic serializer for Perl hashes
 
 =head1 DESCRIPTION
 
+Serializes a vanilla Perl hash to a SOAP::OutputStream.
+Note that Perl hashes are unordered, so the serialization order
+is not guaranteed. Use SOAP::Struct as opposed to a hash if you
+need to preserve order (this is actually a requirement of the
+SOAP spec).
+
+=head1 DEPENDENCIES
+
+SOAP::Serializer
+
 =head1 AUTHOR
 
 Keith Brown
